const chalk = require('chalk');
const SFW = require('./lib/sfw');
const NSFW = require('./lib/nsfw');
const { version } = require('../package.json');

/**
* LunarAPI - The official JavaScript wrapper for Lunar API
* @class Client
*/
class LunarAPI {
	/**
     * @constructor
     * @param {string} token - Your Lunar API Token.
     */
	constructor(token) {
		if (typeof token !== 'string') throw new Error(`${chalk.magenta('LunarAPI')} ${chalk.gray('»')} ${chalk.yellow('Error whilst attempting to authenticate. Make sure your token is a string.')}`);

		/**
         * The base URL.
         * @type {string}
         */
		this.baseURL = 'https://api.lunardev.group';

		/**
         * The wrapper version.
         * @type {string}
         */
		this.version = version;

		// Generators goes here

		/**
         * The SFW module.
         * @type {SFW}
         */
		this.sfw = new SFW(token, `${this.baseURL}/sfw/`);

		/**
         * The NSFW module.
         * @type {NSFW}
         */
		this.nsfw = new NSFW(token, `${this.baseURL}/nsfw/`);
	}
}

module.exports = LunarAPI;