const { get } = require('node-superfetch');
const chalk = require('chalk');
const { version } = require('../../package.json');

/**
* @class SFW
*/
class SFW {
	constructor(token, baseURL) {
		/**
         * Your Lunar API Token.
         * @type {string}
         * @private
        */
		this.token = token;

		/**
          * The base URL.
          * @type {string}
          * @private
         */
		this.baseURL = baseURL;
	}

	/**
      * Returns a random GIF under the 'hug' endpoint.
	  * @param {boolean} json - Whether to return the Image ID instead of the image URL.
      * @returns {Promise<string>} The raw JSON response if json is true
      */
	async hug(json) {

		try {
			const { body } = await get(`${this.baseURL}/hug`)
				.set('Authorization', `Bearer ${this.token}`)
				.set('User-Agent', `LunarAPI » v${version}`);
			if (json) {
				return body;
			}
			else {
				return body.url;
			}
		}
		catch (e) {
			throw new Error(`${chalk.magenta('LunarAPI')} ${chalk.gray('»')} ${chalk.red(`An unknown error has occured!:\n\n${e}`)}`);
		}
	}

	/**
      * Returns a random GIF under the 'pat' endpoint.
	  * @param {boolean} json - Whether to return the Image ID instead of the image URL.
      * @returns {Promise<string>} The raw JSON response if json is true
      */
	async pat(json) {

		try {
			const { body } = await get(`${this.baseURL}/pat`)
				.set('Authorization', `Bearer ${this.token}`)
				.set('User-Agent', `LunarAPI » v${version}`);
			if (json) {
				return body;
			}
			else {
				return body.url;
			}
		}
		catch (e) {
			throw new Error(`${chalk.magenta('LunarAPI')} ${chalk.gray('»')} ${chalk.red(`An unknown error has occured!:\n\n${e}`)}`);
		}
	}
}

module.exports = SFW;